pub struct MockCollectionsApi {
CollectionsApi_expectations: MockCollectionsApi_CollectionsApi,
}Fields
CollectionsApi_expectations: MockCollectionsApi_CollectionsApiImplementations
Sourceimpl MockCollectionsApi
impl MockCollectionsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockCollectionsApi
impl MockCollectionsApi
Sourcepub fn expect_delete(&mut self) -> &mut Expectation
pub fn expect_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete method
Sourcepub fn expect_delete_many(&mut self) -> &mut Expectation
pub fn expect_delete_many(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete_many method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_all(&mut self) -> &mut Expectation
pub fn expect_get_all(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_all method
Sourcepub fn expect_get_details(&mut self) -> &mut Expectation
pub fn expect_get_details(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_details method
Sourcepub fn expect_get_many_with_details(&mut self) -> &mut Expectation
pub fn expect_get_many_with_details(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_many_with_details method
Sourcepub fn expect_get_user(&mut self) -> &mut Expectation
pub fn expect_get_user(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_user method
Sourcepub fn expect_get_users(&mut self) -> &mut Expectation
pub fn expect_get_users(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_users method
Sourcepub fn expect_post(&mut self) -> &mut Expectation
pub fn expect_post(&mut self) -> &mut Expectation
Create an Expectation for mocking the post method
Sourcepub fn expect_post_bulk_collection_access(&mut self) -> &mut Expectation
pub fn expect_post_bulk_collection_access(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_bulk_collection_access method
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method